@@ -18,6 +18,9 @@ RECONSTRUCTION_POSE_PAIR_SCORE_SUMMARY_METHOD = 'rms'
 RECONSTRUCTION_POSE_3D_GRAPH_INITIAL_EDGE_THRESHOLD = 2
 RECONSTRUCTION_POSE_3D_GRAPH_MAX_DISPERSION = 0.20
 RECONSTRUCTION_INCLUDE_TRACK_LABELS = False
+RECONSTRUCTION_PARALLEL = False
+RECONSTRUCTION_NUM_PARALLEL_PROCESSES = None
+RECONSTRUCTION_NUM_CHUNKS = None
 
 # 3D pose spatial limit defaults
 POSE_3D_FLOOR_Z = 0.0
